#!/bin/bash
#
# Caddy Service

PATH=$HOME/.docker/cli-plugins:/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin
get_appvars

config_caddy() {
  echo -ne "\n* Configuring /federated/apps/caddy container.."
  spin &
  SPINPID=$!

  if [ ! -d "/federated/apps/caddy" ]; then
    mkdir -p /federated/apps/caddy/data/data
    mkdir -p /federated/apps/caddy/data/srv
    mkdir -p /federated/apps/caddy/data/etc/caddy
  fi

cat > /federated/apps/caddy/docker-compose.yml <<EOF
version: "3.7"

services:
  caddy:
    image: federatedcomputer/caddy:\${IMAGE_VERSION}
    container_name: caddy
    hostname: caddy.$DOMAIN
    domainname: $DOMAIN
    restart: always
    networks:
      federated:
        ipv4_address: 172.99.0.31
    extra_hosts:
      - "gitea.$DOMAIN:$EXTERNALIP"
    env_file:
      - ./.env
    volumes:
      - ./data/srv:/srv
      - ./data/etc/caddy/Caddyfile:/etc/caddy/Caddyfile
      - ./data/data:/data
    labels:
      - "traefik.enable=true"
      - "traefik.http.routers.caddy.rule=Host(\`caddy.$DOMAIN\`,\`blog.$DOMAIN\`)"
      - "traefik.http.routers.caddy.entrypoints=websecure"
      - "traefik.http.routers.caddy.tls.certresolver=letsencrypt"

networks:
  federated:
    external: true
EOF

cat > /federated/apps/caddy/.env <<EOF
IMAGE_VERSION="latest"
EOF
chmod 600 /federated/apps/caddy/.env

cat > /federated/apps/caddy/data/etc/caddy/Caddyfile <<EOF
$DOMAIN:80 {
  root * /srv/www/public
  file_server
}
caddy.$DOMAIN:80 {
  root * /srv/www/public
  file_server
  route /webhook {
    webhook {
      repo https://gitea.$DOMAIN/gitea/www
      type github
      secret $WEBHOOK_SECRET
      submodule
      token $GITEA_TOKEN_1
      path www
      branch master
    }
  }
}
blog.$DOMAIN:80 {
  root * /srv/blog/public
  file_server
  route /webhook {
    webhook {
      repo https://gitea.$DOMAIN/gitea/blog
      type github
      secret $WEBHOOK_SECRET
      submodule
      token $GITEA_TOKEN_1
      path blog
      branch master
    }
  }
}
documentation.$DOMAIN:80 {
  root * /srv/documentation/public
  file_server
  route /webhook {
    webhook {
      repo https://gitea.$DOMAIN/gitea/documentation
      type github
      secret $WEBHOOK_SECRET
      submodule
      token $GITEA_TOKEN_1
      path documentation
      branch master
    }
  }
}
EOF

kill -9 $SPINPID &> /dev/null
echo -ne "done."
}
email_caddy() {
  echo -ne "* Sending email to customer.."
  spin &
  SPINPID=$!

cat > /federated/apps/mail/data/root/certs/mailfile <<EOF
<html>
<img src="https://www.federated.computer/wp-content/uploads/2023/11/logo.png" alt="" /><br>
<p>
<h4>Caddy is now installed on $DOMAIN</h4>
<p>
Here is your applications chart with on how to access this service:<br>
<p>
<h4>Applications</h4>
<style type="text/css">
.tg  {border-collapse:collapse;border-spacing:0;}
.tg td{border-color:black;border-style:solid;border-width:1px;font-family:Arial, sans-serif;font-size:14px;
  overflow:hidden;padding:10px 5px;word-break:normal;}
.tg th{border-color:black;border-style:solid;border-width:1px;font-family:Arial, sans-serif;font-size:14px;
  font-weight:normal;overflow:hidden;padding:10px 5px;word-break:normal;}
.tg .tg-cul6{border-color:inherit;color:#340096;text-align:left;text-decoration:underline;vertical-align:top}
.tg .tg-acii{background-color:#FFF;border-color:inherit;color:#333;text-align:left;vertical-align:top}
.tg .tg-0hty{background-color:#000000;border-color:inherit;color:#ffffff;font-weight:bold;text-align:left;vertical-align:top}
.tg .tg-kwiq{border-color:inherit;color:#000000;text-align:left;vertical-align:top;word-wrap:break-word}
.tg .tg-0pky{border-color:inherit;text-align:left;vertical-align:top}
</style>
<table class="tg" style="undefined;table-layout: fixed; width: 996px">
<colgroup>
<col style="width: 101.333333px">
<col style="width: 203.333333px">
<col style="width: 282.333333px">
<col style="width: 185.33333px">
<col style="width: 78.333333px">
<col style="width: 220.333333px">
</colgroup>
<thead>
  <tr>
    <th class="tg-0hty">Service</th>
    <th class="tg-0hty">Link</th>
    <th class="tg-0hty">User / Pass</th>
    <th class="tg-0hty">Access</th>
    <th class="tg-0hty">Docs</th>
    <th class="tg-0hty">Description</th>
  </tr>
</thead>
<tbody>
  <tr>
    <td class="tg-kwiq">Caddy</td>
    <td class="tg-kwiq"><a href="https://caddy.$DOMAIN" target="_blank" rel="noopener noreferrer"><span style="color:#340096">caddy.$DOMAIN</span></a></td>
    <td class="tg-kwiq">No login/td>
    <td class="tg-kwiq">No login</td>
    <td class="tg-kwiq"><a href="https://documentation.federated.computer/docs/getting_started/welcome/" target="_blank" rel="noopener noreferrer"><span style="color:#340096">Click here</span></a></td>
    <td class="tg-kwiq">Caddy is a powerful, enterprise-ready, open source web server</td>
  </tr>
</tbody>
</table>
<h4>Thanks for your support!</h4>
<p>
Thank you for your support of Federated Computer. We really appreciate it and hope you have a very successful
time with Federated Core.
<p>
Again, if we can be of any assistance, please don't hesitate to get in touch.
<p>
Support: https://support.federated.computer<br>
Phone: (970) 722-8715<br>
Email: support@federated.computer<br>
<p>
It's <b>your</b> computer. Let's make it work for you!
</html>
EOF

  # Send out e-mail from mail container with details
  docker exec mail bash -c "mail -r admin@$DOMAIN -a \"Content-type: text/html\" -s \"Application installed on $DOMAIN\" $EMAIL < /root/certs/mailfile"
  rm /federated/apps/mail/data/root/certs/mailfile

  kill -9 $SPINPID &> /dev/null
  echo -ne "done.\n"
}
uninstall_caddy() {
  echo -ne "* Uninstalling caddy container.."
  spin &
  SPINPID=$!

  # First stop the service
  cd /federated/apps/caddy && docker-compose -f docker-compose.yml -p caddy down &> /dev/null

  # Delete the app directory
  rm -rf /federated/apps/caddy

  kill -9 $SPINPID &> /dev/null
  echo -ne "done.\n"
}
start_caddy() {
  # Start service with command and retry amount to make sure it's up before proceeding
  start_service "caddy" "nc -z 172.99.0.31 80 &> /dev/null" "7"

  kill -9 $SPINPID &> /dev/null
  echo -ne "done."
}
